@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2015-04-04'; # DATE
-our $VERSION = '0.34'; # VERSION
+our $DATE = '2015-04-07'; # DATE
+our $VERSION = '0.35'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -309,7 +309,8 @@ sub _process_script {
                     'common' ~~ @{ $opts->{$name}{tags} // []};
             };
 
-            # first display common options
+            # first display options tagged with 'common' (that are supposed to
+            # be the same across subcommands)
             {
                 use experimental 'smartmatch';
                 my $opts = $clidocdata{ $sc_names[0] }{opts};
@@ -327,7 +328,8 @@ sub _process_script {
                 push @content, "=back\n\n";
             }
 
-            # display each subcommand's options (without the common options)
+            # display each subcommand's options (without the options tagged as
+            # 'common')
             for my $sc_name (@sc_names) {
                 my $sc_spec = $cli->{subcommands}{$sc_name};
                 next if $sc_spec->{is_alias};
@@ -349,19 +351,23 @@ sub _process_script {
         } else {
             my $opts = $clidocdata{''}{opts};
             # find all the categories
-            my %cats; # val=[options...]
+            my %options_by_cat; # val=[options...]
             for (keys %$opts) {
-                push @{ $cats{$opts->{$_}{category}} }, $_;
+                push @{ $options_by_cat{$opts->{$_}{category}} }, $_;
             }
-            for my $cat (sort keys %cats) {
+            my $cats_spec = $clidocdata{''}{option_categories};
+            for my $cat (sort {
+                ($cats_spec->{$a}{order} // 50) <=> ($cats_spec->{$b}{order} // 50)
+                    || $a cmp $b }
+                             keys %options_by_cat) {
                 push @content, "=head2 $cat\n\n"
-                    unless keys(%cats) == 1;
+                    unless keys(%options_by_cat) == 1;
 
                 my @opts = sort {
                     (my $a_without_dash = $a) =~ s/^-+//;
                     (my $b_without_dash = $b) =~ s/^-+//;
                     lc($a) cmp lc($b);
-                } @{ $cats{$cat} };
+                } @{ $options_by_cat{$cat} };
                 push @content, "=over\n\n";
                 for (@opts) {
                     next if 'hidden' ~~ @{ $opts->{$_}{tags} // [] };
@@ -477,7 +483,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.34 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-04-04.
+This document describes version 0.35 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-04-07.
 
 =head1 SYNOPSIS
 
@@ -574,7 +580,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-Rinci>.
+Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-Perinci>.
 
 =head1 BUGS
 
